@@ -1,9 +1,15 @@
-__version__ = '1.0.20'
+__version__ = "1.1.0"
 
 
 def setup(app):
-    from . import autodoc_mods, dialect_info, mako, \
-        sqlformatter, viewsource, scss
+    from . import (
+        autodoc_mods,
+        dialect_info,
+        mako,
+        sqlformatter,
+        viewsource,
+        scss,
+    )
 
     autodoc_mods.setup(app)
     dialect_info.setup(app)
