@@ -2,10 +2,13 @@ import re
 
 
 def autodoc_skip_member(app, what, name, obj, skip, options):
-    if what == 'class' and skip and \
-        name in ('__init__', '__eq__', '__ne__', '__lt__',
-                    '__le__', '__call__') and \
-        obj.__doc__:
+    if (
+        what == "class"
+        and skip
+        and name
+        in ("__init__", "__eq__", "__ne__", "__lt__", "__le__", "__call__")
+        and obj.__doc__
+    ):
         return False
     else:
         return skip
@@ -19,6 +22,7 @@ def _adjust_rendered_mod_name(config, modname, objname):
     else:
         return modname
 
+
 # im sure this is in the app somewhere, but I don't really
 # know where, so we're doing it here.
 _track_autodoced = {}
@@ -36,22 +40,16 @@ def autodoc_process_docstring(app, what, name, obj, options, lines):
         for base in obj.__bases__:
             if base is not object:
                 adjusted_mod = _adjust_rendered_mod_name(
-                    app.env.config, base.__module__, base.__name__)
-                bases.append(
-                    ":class:`%s.%s`" % (
-                        adjusted_mod,
-                        base.__name__))
-                _inherited_names.add(
-                    "%s.%s" % (adjusted_mod, base.__name__))
+                    app.env.config, base.__module__, base.__name__
+                )
+                bases.append(":class:`%s.%s`" % (adjusted_mod, base.__name__))
+                _inherited_names.add("%s.%s" % (adjusted_mod, base.__name__))
 
         if bases:
-            lines[:0] = [
-                "Bases: %s" % (", ".join(bases)),
-                ""
-            ]
+            lines[:0] = ["Bases: %s" % (", ".join(bases)), ""]
 
     elif what in ("attribute", "method"):
-        m = re.match(r'(.*?)\.([\w_]+)$', name)
+        m = re.match(r"(.*?)\.([\w_]+)$", name)
         if m:
             clsname, attrname = m.group(1, 2)
             if clsname in _track_autodoced:
@@ -61,45 +59,62 @@ def autodoc_process_docstring(app, what, name, obj, options, lines):
                         break
                 if supercls is not cls:
                     adjusted_mod = _adjust_rendered_mod_name(
-                        app.env.config,
-                        supercls.__module__,
-                        supercls.__name__
+                        app.env.config, supercls.__module__, supercls.__name__
                     )
 
                     _inherited_names.add(
-                        "%s.%s" % (adjusted_mod, supercls.__name__))
+                        "%s.%s" % (adjusted_mod, supercls.__name__)
+                    )
                     _inherited_names.add(
-                        "%s.%s.%s" %
-                        (adjusted_mod, supercls.__name__, attrname))
+                        "%s.%s.%s"
+                        % (adjusted_mod, supercls.__name__, attrname)
+                    )
                     lines[:0] = [
                         ".. container:: inherited_member",
                         "",
                         "    *inherited from the* "
-                        ":%s:`~%s.%s.%s` *%s of* :class:`~%s.%s`" % (
-                            "attr" if what == "attribute"
-                            else "meth",
+                        ":%s:`~%s.%s.%s` *%s of* :class:`~%s.%s`"
+                        % (
+                            "attr" if what == "attribute" else "meth",
                             adjusted_mod,
                             supercls.__name__,
                             attrname,
                             what,
                             adjusted_mod,
-                            supercls.__name__
+                            supercls.__name__,
                         ),
-                        ""
+                        "",
                     ]
 
 
 def missing_reference(app, env, node, contnode):
-    if node.attributes['reftarget'] in _inherited_names:
+    if node.attributes["reftarget"] in _inherited_names:
         return node.children[0]
     else:
         return None
 
 
-def setup(app):
-    app.connect('autodoc-skip-member', autodoc_skip_member)
-    app.connect('autodoc-process-docstring', autodoc_process_docstring)
-    app.add_config_value("autodocmods_convert_modname", {}, 'env')
-    app.add_config_value("autodocmods_convert_modname_w_class", {}, 'env')
+def work_around_issue_6785():
+    """See https://github.com/sphinx-doc/sphinx/issues/6785
+    """
 
-    app.connect('missing-reference', missing_reference)
+    from sphinx.ext import autodoc
+
+    # check some assumptions, more as a way of testing if this code changes
+    # on the sphinx side
+    assert (
+        autodoc.PropertyDocumenter.priority
+        > autodoc.AttributeDocumenter.priority
+    )
+    autodoc.PropertyDocumenter.priority = -100
+
+
+def setup(app):
+    work_around_issue_6785()
+
+    app.connect("autodoc-skip-member", autodoc_skip_member)
+    app.connect("autodoc-process-docstring", autodoc_process_docstring)
+    app.add_config_value("autodocmods_convert_modname", {}, "env")
+    app.add_config_value("autodocmods_convert_modname_w_class", {}, "env")
+
+    app.connect("missing-reference", missing_reference)
